#
# spec file for package xsel
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2010 Guido Berhoerster.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           xsel
Version:        1.2.1
Release:        1.2
Summary:        Command-line Program for Getting and Setting the Contents of the X Selection
License:        MIT
Source:         https://github.com/kfish/xsel/archive/refs/tags/%{version}.tar.gz#/%{name}-%{version}.tar.gz
URL:            http://www.kfish.org/software/xsel/
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  libtool
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xt)

%description
XSel is a command-line program for getting and setting the contents of the X
selection. Normally this is only accessible by manually highlighting
information and pasting it with the middle mouse button.

%prep
%autosetup -p1

%build
./autogen.sh --version
%configure
%make_build

%install
%make_install

%files
%doc AUTHORS ChangeLog README
%doc %{_mandir}/man1/xsel.1x*
%{_bindir}/xsel

%changelog
* Fri Mar  8 2024 Martin Pluskal <mpluskal@suse.com>
- Fix download url
* Thu Mar  7 2024 jun wang <jgwang@suse.com>
- Update to version 1.2.1
  * INCR transfer bug fixes in #16
  * Use XDG_CACHE_HOME for xsel.log in #15
  * Using markdown syntax in #9
  * Plug memory leak in handle_targets in #18
  * Fix segfault when stdin is empty in #17
  * Fix #19 segfault when --append to empty selection in #20
  * Do not modify HOME environment variable in #21
  * Perform fstat on stdin and stdout only if required in #22
  * Debian patches in #25
  * Avoid passing NULL to vsnprintf() in #27
  * Avoid extra char copy in strncpy in #32
  * Set timer value to 0 to stop timer, don't use a nullptr timer
    in #31
  * Remove interfering error message in #37
  * Option: trim trailing newline from output in #39
  * In README file: updated link to ICCCM rant to one that works
    in #40
  * Fix MULTIPLE conversion requests in #45
  * Added option to add window name in #41
  * Set WM_NAME and WM_CLASS window properties in #35
  * Modernize in #50
- Remove disable-werror.patch because it was applied in code
* Wed Apr 26 2023 Jan Engelhardt <jengelh@inai.de>
- Remove pre-SUSE-15 build logic
* Tue May 14 2019 Martin Liška <mliska@suse.cz>
- Add disable-werror.patch in order to handle with a new GCC 9 warning.
* Fri Oct 31 2014 crrodriguez@opensuse.org
- IN current factory, also pkgconfig(xt) seems to be needed.
* Sun Oct 19 2014 crrodriguez@opensuse.org
- In newer products, discontinue the use of metapackage
  xorg-x11-devel, only pkgconfig(x11) is required.
* Thu Nov  3 2011 pascal.bleser@opensuse.org
- build fixes for SLE_10 and SLE_11
* Fri Feb 19 2010 guido+opensuse.org@berhoerster.name
- cleaned up specfile, use separate changes file
* Mon Dec 21 2009 guido+opensuse.org@berhoerster.name
- initial packaging of xsel
